<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="ru_RU" sourcelanguage="">
<context>
    <name>GpxDocument</name>
    <message>
        <location filename="../../gpxviewer/gpxdocument.py" line="171"/>
        <source>This file in not a valid GPX Viewer project file.</source>
        <translation>Этот файл не является файлом проекта GPX Viewer.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxdocument.py" line="102"/>
        <source>One of the files has wrong number of valid waypoints or tracks. This file is likely to be damaged or changed from outside.</source>
        <translation>Один из файлов содержит неправильное количество маршрутных точек или треков. Вероятно, этот файл повреждён или изменён извне.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxdocument.py" line="97"/>
        <source>One of GPX files doesn&apos;t exist. This project can&apos;t be opened.</source>
        <translation>Один из GPX файлов не существует. Невозможно открыть проект.</translation>
    </message>
</context>
<context>
    <name>GpxMainWindow</name>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="59"/>
        <source>Filter by name:</source>
        <translation>Фильтр по названию:</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="62"/>
        <source>Enter regular expression</source>
        <translation>Регулярное выражение</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="153"/>
        <source>Neglect previous distance</source>
        <translation>Не учитывать предыдущее расстояние</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="182"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="157"/>
        <source>Point style</source>
        <translation>Стиль точек</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="252"/>
        <source>GPX Viewer Help</source>
        <translation>Справка GPX Viewer</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="223"/>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="224"/>
        <source>Using</source>
        <translation>Используется</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="228"/>
        <source>License:</source>
        <translation>Лицензия:</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="229"/>
        <source>About GPX Viewer</source>
        <translation>О GPX Viewer</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="484"/>
        <source>Distance Profile</source>
        <translation>Профиль по расстоянию</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="509"/>
        <source>Time Profile</source>
        <translation>Профиль по времени</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="465"/>
        <source>Open GPX file</source>
        <translation>Открыть GPX файл</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="391"/>
        <source>Open project file</source>
        <translation>Открыть файл проекта</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="407"/>
        <source>Save project file as</source>
        <translation>Сохранить файл проекта как</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="145"/>
        <source>Skip points</source>
        <translation>Пропустить точки</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="147"/>
        <source>Points with markers</source>
        <translation>Точки с маркерами</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="149"/>
        <source>Points with captions and markers</source>
        <translation>Точки с подписями и маркерами</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="151"/>
        <source>Points with splitting lines</source>
        <translation>Точки с разделительными линиями</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="126"/>
        <source>Close GPX Viewer</source>
        <translation>Зактыть GPX Viewer</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="381"/>
        <source>There are unsaved changes. Do you want to save the project?</source>
        <translation>Есть несохранённые изменения. Вы хотите сохранить проект?</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="350"/>
        <source>Load GPX file</source>
        <translation>Загрузить GPX файл</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="381"/>
        <source>Open GPX Viewer project</source>
        <translation>Открыть проект GPX Viewer</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="465"/>
        <source>GPX XML (*.gpx);;All files (*)</source>
        <translation>GPX XML (*.gpx);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="462"/>
        <source>File read error</source>
        <translation>Ошибка чтения файла</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="407"/>
        <source>GPX Viewer Projects (*.gpxv);;All files (*)</source>
        <translation>Проекты GPX Viewer (*.gpxv);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="438"/>
        <source>Multiple GPX files</source>
        <translation>Несколько GPX файлов</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="373"/>
        <source>Save GPX file as</source>
        <translation>Сохранить GPX файл как</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="519"/>
        <source>Not enouph points.</source>
        <translation>Недостаточно точек.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="370"/>
        <source>The GPX file will be empty.</source>
        <translation>GPX файл будет пуст.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="421"/>
        <source>The project is empty.</source>
        <translation>Проект пуст.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="421"/>
        <source>Save error</source>
        <translation>Ошибка сохранения</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="506"/>
        <source>Plot error</source>
        <translation>Ошибка отрисовки</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="519"/>
        <source>Statistics error</source>
        <translation>Ошибка расчёта статистики</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="180"/>
        <source>Skip tracks</source>
        <translation>Пропустить треки</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="506"/>
        <source>Not enouph points or tracks.</source>
        <translation>Недостаточно точек или треков.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="232"/>
        <source>Notation:&lt;br&gt;
                           &lt;font color=red&gt;Red&lt;/font&gt; - skipped points&lt;br&gt;
                           &lt;font color=blue&gt;Blue&lt;/font&gt; - marked points&lt;br&gt;
                           &lt;font color=green&gt;Green&lt;/font&gt; - captioned points&lt;br&gt;
                           &lt;b&gt;Bold&lt;/b&gt; - points with splitting lines&lt;br&gt;
                           &lt;i&gt;Italic&lt;/i&gt; - distance before these points is neglected&lt;br&gt;
                           &lt;br&gt;
                           Useful shortcuts:&lt;br&gt;
                           Ctrl+C - Copy points to clipboard&lt;br&gt;
                           Ctrl+P - Show distance profile&lt;br&gt;
                           Ctrl+T - Show time profile&lt;br&gt;
                           Ctrl+I - Show statistics&lt;br&gt;
                           &lt;br&gt;
                           Several cases are possible when plotting a profile:
                           &lt;ul&gt;
                           &lt;li&gt;All non-skipped points have timestamps: points and tracks with timestamps are taken into account&lt;/li&gt;
                           &lt;li&gt;There are points without timestamps: only points are considered, tracks are skipped&lt;/li&gt;
                           &lt;li&gt;There are no points: all non-skipped tracks are taken into account&lt;/li&gt;
                           &lt;/ul&gt;</source>
        <translation>Обозначения:&lt;br&gt;
                           &lt;font color=red&gt;Красный&lt;/font&gt; - пропущенные точки&lt;br&gt;
                           &lt;font color=blue&gt;Синий&lt;/font&gt; - точки с маркерами&lt;br&gt;
                           &lt;font color=green&gt;Зелёный&lt;/font&gt; - точки с подписями&lt;br&gt;
                           &lt;b&gt;Полужирный&lt;/b&gt; - точки с разделительными линиями&lt;br&gt;
                           &lt;i&gt;Курсив&lt;/i&gt; - расстояние перед этими точками пропущено&lt;br&gt;
                           &lt;br&gt;
                           Комбинации клавиш:&lt;br&gt;
                           Ctrl+C - Копировать точки в буфер обмена&lt;br&gt;
                           Ctrl+P - Показать профиль по расстоянию&lt;br&gt;
                           Ctrl+T - Показать профиль по времени &lt;br&gt;
                           Ctrl+I - Показать статистику&lt;br&gt;
                           &lt;br&gt;
                           При рисовании профиля возможно несколько случаев:
                           &lt;ul&gt;
                           &lt;li&gt;Все непропущенные точки имеют отметки времени: учитываются точки и треки с отметками времени&lt;/li&gt;
                           &lt;li&gt;Есть точки без отметок времени: учитываются только точки, треки пропускаются&lt;/li&gt;
                           &lt;li&gt;Нет точек: учитываются все непропущенные треки&lt;/li&gt;
                           &lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="159"/>
        <source>Show on Google maps</source>
        <translation>Показать на карте Google</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="462"/>
        <source>The file </source>
        <translation>Файл </translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmainwindow.py" line="462"/>
        <source> doesn&apos;t exist.

Do you want to choose another location of this file?</source>
        <translation> не существует.

Вы хотите выбрать другое расположение этого файла?</translation>
    </message>
</context>
<context>
    <name>GpxParser</name>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="240"/>
        <source> is an invalid GPX file.</source>
        <translation> повреждённый GPX файл.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="294"/>
        <source>Waypoint </source>
        <translation>Маршрутная точка </translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="355"/>
        <source>Track </source>
        <translation>Трек </translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="294"/>
        <source>is invalid and will be skipped.</source>
        <comment>Waypoint</comment>
        <translation>повреждена и будет пропущена.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="355"/>
        <source>is invalid and will be skipped.</source>
        <comment>Track</comment>
        <translation>повреждён и будет пропущен.</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="355"/>
        <source>File read error</source>
        <translation>Ошибка чтения файла</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="208"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="214"/>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="215"/>
        <source>&amp;Open project</source>
        <translation>&amp;Открыть проект</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="216"/>
        <source>&amp;About Qt</source>
        <translation>&amp;О Qt</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="217"/>
        <source>&amp;Save project</source>
        <translation>&amp;Сохранить проект</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="218"/>
        <source>Save project &amp;as...</source>
        <translation>Сохранить проект &amp;как...</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="219"/>
        <source>&amp;Load GPX file</source>
        <translation>&amp;Загрузить GPX файл</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="223"/>
        <source>&amp;Show skipped</source>
        <translation>&amp;Показывать пропущенные</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="224"/>
        <source>Show &amp;marked</source>
        <translation>Показывать &amp;маркированные</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="225"/>
        <source>Show &amp;captioned</source>
        <translation>Показывать &amp;подписанные</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="226"/>
        <source>Show &amp;other</source>
        <translation>Показывать &amp;остальные</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="206"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="209"/>
        <source>F&amp;ilter</source>
        <translation>Ф&amp;ильтр</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="220"/>
        <source>&amp;Distance profile</source>
        <translation>&amp;Профиль по расстоянию</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="221"/>
        <source>&amp;Time profile</source>
        <translation>Профиль по &amp;времени</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="227"/>
        <source>GPX Viewer &amp;Help</source>
        <translation>&amp;Справка GPX Viewer</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="228"/>
        <source>About &amp;GPX Viewer</source>
        <translation>О &amp;GPX Viewer</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="204"/>
        <source>Waypoints</source>
        <translation>Маршрутные точки</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="229"/>
        <source>&amp;New project</source>
        <translation>&amp;Новый проект</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="230"/>
        <source>&amp;Statistics</source>
        <translation>&amp;Статистика</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="231"/>
        <source>Save &amp;GPX file as...</source>
        <translation>Сохранить &amp;GPX файл как...</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="205"/>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="211"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="212"/>
        <source>Tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="213"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="210"/>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="222"/>
        <source>&amp;Profile style</source>
        <translation>&amp;Стиль профиля</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="207"/>
        <source>&amp;Recent projects</source>
        <translation>&amp;Недавние проекты</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_mainwindow.py" line="232"/>
        <source>&amp;Clear list</source>
        <translation>&amp;Очистить список</translation>
    </message>
</context>
<context>
    <name>PlotCanvas</name>
    <message>
        <location filename="../../gpxviewer/plotcanvas.py" line="88"/>
        <source>Time (days)</source>
        <translation>Время (дни)</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotcanvas.py" line="91"/>
        <source>Altitude (m)</source>
        <translation>Высота (м)</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotcanvas.py" line="90"/>
        <source>Time (hours)</source>
        <translation>Время (часы)</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotcanvas.py" line="83"/>
        <source>Distance (km)</source>
        <translation>Расстояние (км)</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotcanvas.py" line="85"/>
        <source>Distance with coefficient </source>
        <translation>Расстояние с коэффициентом </translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotcanvas.py" line="85"/>
        <source> (km)</source>
        <translation> (км)</translation>
    </message>
</context>
<context>
    <name>PlotWindow</name>
    <message>
        <location filename="../../gpxviewer/ui_plotwindow.py" line="47"/>
        <source>Export current size</source>
        <translation>Экспорт текущего размера</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_plotwindow.py" line="49"/>
        <source>Export selected size</source>
        <translation>Экспорт выбранного размера</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotviewer.py" line="40"/>
        <source>Set size for export:</source>
        <translation>Размер для экспорта:</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotviewer.py" line="83"/>
        <source>Export profile of the current size</source>
        <translation>Экспортировать профиль текущего размера</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotviewer.py" line="89"/>
        <source>Export profile of the selected size</source>
        <translation>Экспортировать профиль выбранного размера</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/plotviewer.py" line="68"/>
        <source>Encapsulated Postscript (*.eps);;Portable Document Format (*.pdf);;PGF files (*.pgf);;PNG images (*.png);;Postscript files (*.ps);;SVG files (*.svg);;SVGZ files (*.svgz);;All files (*.*)</source>
        <translation>Encapsulated Postscript (*.eps);;Portable Document Format (*.pdf);;Файлы PGF (*.pgf);;Изображения PNG (*.png);;Файлы Postscript (*.ps);;Файлы SVG (*.svg);;Файлы SVGZ (*.svgz);;Все файлы (*.*)</translation>
    </message>
</context>
<context>
    <name>PointConfigDialog</name>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="40"/>
        <source>Point</source>
        <translation>Точка</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="41"/>
        <source>Pixel</source>
        <translation>Пиксель</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="42"/>
        <source>Circle</source>
        <translation>Круг</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="43"/>
        <source>Triangle down</source>
        <translation>Треугольник вниз</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="44"/>
        <source>Triangle up</source>
        <translation>Треугольник вверх</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="45"/>
        <source>Triangle left</source>
        <translation>Треугольник влево</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="46"/>
        <source>Triangle right</source>
        <translation>Треугольник вправо</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="47"/>
        <source>Tri down</source>
        <translation>Трилистник вниз</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="48"/>
        <source>Tri up</source>
        <translation>Трилистник вверх</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="49"/>
        <source>Tri left</source>
        <translation>Трилистник влево</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="50"/>
        <source>Tri right</source>
        <translation>Трилистник вправо</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="51"/>
        <source>Square</source>
        <translation>Квадрат</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="52"/>
        <source>Pentagon</source>
        <translation>Пятиугольник</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="53"/>
        <source>Star</source>
        <translation>Звезда</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="54"/>
        <source>Hexagon 1</source>
        <translation>Шестиугольник 1</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="55"/>
        <source>Hexagon 2</source>
        <translation>Шестиугольник 2</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="56"/>
        <source>Plus</source>
        <translation>Плюс</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="57"/>
        <source>X</source>
        <translation>Крест</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="58"/>
        <source>Diamond</source>
        <translation>Ромб</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="59"/>
        <source>Thin diamond</source>
        <translation>Узкий ромб</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="60"/>
        <source>Vertical line</source>
        <translation>Вертикальная линия</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="61"/>
        <source>Horizontal line</source>
        <translation>Горизонтальная линия</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="62"/>
        <source>Solid</source>
        <translation>Сплошная</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="63"/>
        <source>Dashed</source>
        <translation>Пунктирная</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="64"/>
        <source>Dash-dot</source>
        <translation>Штрих-пунктирная</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/pointconfigdialog.py" line="65"/>
        <source>Dotted</source>
        <translation>Штриховая</translation>
    </message>
</context>
<context>
    <name>StatWindow</name>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="120"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="130"/>
        <source>Distance</source>
        <translation>Расстояние</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="133"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="129"/>
        <source>Total</source>
        <translation>Всего</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="118"/>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="134"/>
        <source>By splitting lines</source>
        <translation>По разделительным линиям</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/statwindow.py" line="41"/>
        <source>By name:</source>
        <translation>По названию:</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/statwindow.py" line="45"/>
        <source>Enter regular expression</source>
        <translation>Регулярное выражение</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="131"/>
        <source>Elevation ascent</source>
        <translation>Набор высоты</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_statwindow.py" line="132"/>
        <source>Elevation descent</source>
        <translation>Сброс высоты</translation>
    </message>
</context>
<context>
    <name>TrkModel</name>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="173"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="173"/>
        <source>Length</source>
        <translation>Длина</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="173"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="173"/>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="173"/>
        <source>Segments</source>
        <translation>Сегменты</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="173"/>
        <source>Points</source>
        <translation>Точки</translation>
    </message>
</context>
<context>
    <name>WptModel</name>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="41"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="41"/>
        <source>Latitude</source>
        <translation>Широта</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="41"/>
        <source>Longitude</source>
        <translation>Долгота</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
        <source>Distance</source>
        <translation>Расстояние</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
        <source>Time difference</source>
        <translation>Разница во времени</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
        <source>Time in days</source>
        <translation>Время в днях</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/gpxmodel.py" line="41"/>
        <source>Elevation</source>
        <translation>Высота</translation>
    </message>
</context>
<context>
    <name>pointConfigDialog</name>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="280"/>
        <source>Configure point style</source>
        <translation>Настроить стиль точек</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="281"/>
        <source>Marker style</source>
        <translation>Стиль маркера</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="282"/>
        <source>Marker color</source>
        <translation>Цвет маркера</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="283"/>
        <source>Marker size</source>
        <translation>Размер маркера</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="284"/>
        <source>Split line style</source>
        <translation>Стиль разделительной линии</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="285"/>
        <source>Split line color</source>
        <translation>Цвет разделительной линии</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="286"/>
        <source>Split line width</source>
        <translation>Толщина разделительной линии</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="287"/>
        <source>Caption position (x, y)</source>
        <translation>Положение подписи (x, y)</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_pointconfigdialog.py" line="288"/>
        <source>Caption size</source>
        <translation>Размер подписи</translation>
    </message>
</context>
<context>
    <name>profileConfigDialog</name>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="138"/>
        <source>Configure profile style</source>
        <translation>Настроить стиль профиля</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="139"/>
        <source>Profile color</source>
        <translation>Цвет профиля</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="140"/>
        <source>Fill color</source>
        <translation>Цвет заполнения</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="141"/>
        <source>Profile width</source>
        <translation>Толщина профиля</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="142"/>
        <source>Minimum altitude</source>
        <translation>Минимальная высота</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="143"/>
        <source>Maximum altitude</source>
        <translation>Максимальная высота</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="145"/>
        <source>Time zone offset</source>
        <translation>Сдвиг часового пояса</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="146"/>
        <source> min</source>
        <translation> мин</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="144"/>
        <source>Distance coefficient</source>
        <translation>Коэффициент расстояния</translation>
    </message>
    <message>
        <location filename="../../gpxviewer/ui_profileconfigdialog.py" line="147"/>
        <source>Use only selected points</source>
        <translation>Только выделенные точки</translation>
    </message>
</context>
</TS>
